const buildState = ({ theme, color, backgroundColor, borderColor }) => {
	return {
		color: color || theme('colors.white'),
		backgroundColor: backgroundColor,
		borderColor: borderColor,
		boxShadow: `0 3px ${borderColor}`,
		'&.button--blank': {
			color: color || backgroundColor,
			backgroundColor: theme('colors.white'),
			borderColor: theme('colors.gray.200'),
			boxShadow: `0 3px ${theme('colors.gray.200')}`,
		},
		'&:active:not(:disabled)': {
			boxShadow: `0 0 ${borderColor}`,
			transform: 'translateY(3px)',
		},
	};
};

const button = (theme) => ({
	'.button': {
		padding: `${theme('spacing.2')} ${theme('spacing.4')}`,
		margin: `${theme('spacing.2')} auto`,

		display: 'flex',
		justifyContent: 'center',

		width: '100%',
		height: '40px',

		fontSize: '14px',

		borderRadius: theme('borderRadius.lg'),
		border: '1px solid',

		textTransform: 'uppercase',
		fontWeight: theme('fontWeight.bold'),

		'&--none': buildState({
			theme,
			color: theme('colors.gray.500'),
			backgroundColor: theme('colors.white'),
			borderColor: theme('colors.gray.200'),
		}),
		'&--info': buildState({
			theme,
			backgroundColor: theme('colors.info.200'),
			borderColor: theme('colors.info.300'),
		}),
		'&--success': buildState({
			theme,
			backgroundColor: theme('colors.success.200'),
			borderColor: theme('colors.success.300'),
		}),
		'&--warning': buildState({
			theme,
			backgroundColor: theme('colors.warning.200'),
			borderColor: theme('colors.warning.300'),
		}),
		'&--error': buildState({
			theme,
			backgroundColor: theme('colors.error.100'),
			borderColor: theme('colors.error.300'),
		}),
		'&:disabled': {
			color: theme('colors.gray.200'),
			backgroundColor: theme('colors.gray.50'),
			borderColor: theme('colors.gray.50'),
			boxShadow: `0 0px ${theme('colors.gray.50')}`,
			transform: 'translateY(3px)',
			cursor: 'not-allowed',
		},

		'&--pressed': {
			boxShadow: 'none',
			transform: 'translateY(3px)',
		},
	},
});

module.exports = ({ addComponents, theme }) => {
	addComponents(button(theme));
};

module.exports.button = button;
