const buildState = ({ color }) => ({
	'& .field-label': {
		color: color,
	},
});

const field = (theme) => ({
	'.form-field-container': {
		marginBottom: '.75rem',
	},
	'.field': {
		'&-container': {
			display: 'flex',
			fontSize: '15px',
			alignItems: 'center',
			'&--multiline': {
				alignItems: 'baseline',
			},
			'&--info': buildState({ color: theme('colors.info.200') }),
			'&--success': buildState({ color: theme('colors.success.200') }),
			'&--warning': buildState({ color: theme('colors.warning.200') }),
			'&--error': buildState({ color: theme('colors.error.200') }),
		},
		'&-label': {
			padding: '0.25rem 0.5rem',
			color: theme('colors.primary.500'),
			borderRadius: `${theme('borderRadius.lg')} 0 0 ${theme('borderRadius.lg')}`,
			border: `1px solid ${theme('colors.gray.300')}`,
			backgroundColor: 'white',
			borderRightWidth: 0,
			whiteSpace: 'nowrap',
			height: '2.5rem',
			display: 'flex',
			alignItems: 'center',
			'& > svg': {
				fontSize: '1.4rem',
			},
			'&--multiline': {
				height: 'auto',
				alignItems: 'baseline',
				alignSelf: 'normal',
			},
			'&--disabled': {
				borderColor: theme('colors.gray.100'),
			},
		},
		'&-input': {
			padding: '0.25rem 0.25rem',
			outline: 'none',
			height: '2.5rem',
			width: '100%',
			fontWeight: 300,
			boxSizing: 'border-box',
			borderRadius: `0 ${theme('borderRadius.lg')} ${theme('borderRadius.lg')} 0`,
			border: '1px solid',
			borderLeftWidth: 0,
			cursor: 'text',
			'&': {
				borderColor: theme('colors.gray.300'),
			},
			'&:disabled': {
				backgroundColor: 'transparent',
				borderColor: theme('colors.gray.100'),
			},
			'&:read-only': {
				cursor: 'auto',
			},
			'&--multiline': {
				minHeight: '4rem',
			},
			'&--nolabel': {
				padding: '0.25rem 0.5rem',
				borderLeft: '1px solid',
				borderColor: theme('colors.gray.300'),
				borderRadius: theme('borderRadius.lg'),
				'&:disabled': {
					border: `1px solid ${theme('colors.gray.50')}`,
				},
			},
		},
	},
	'.checkbox-container, .radiobutton-container, .humanverify-container': {
		'.field-label': {
			borderRadius: theme('borderRadius.lg'),
			borderRightWidth: '1px',
		},
		'.field-checkbox, .field-radio': {
			cursor: 'pointer',
			'& > svg': {
				color: theme('colors.primary.200'),
			},
			'&--disabled': {
				color: theme('colors.gray.100'),
				cursor: 'not-allowed',
				'& > svg': {
					color: theme('colors.gray.100'),
					cursor: 'not-allowed',
				},
			},
		},
		'.field-radiobutton': {
			display: 'flex',
			textAlign: 'center',
			padding: '.35rem',
			alignItems: 'center',
			height: '100%',
			cursor: 'pointer',
			borderRadius: theme('borderRadius.lg'),
			border: `1px solid transparent`,
			'&--disabled': {
				color: theme('colors.gray.100'),
				cursor: 'not-allowed',
			},
			'&--active': {
				borderStyle: 'dashed',
				// borderColor: theme('colors.primary.100'),
				backgroundColor: theme('colors.primary.50'),
			},
		},
	},
	'.field-validationMessage': {
		color: theme('colors.error.300'),
		marginLeft: '0.5rem',
		fontSize: '0.75rem',
	},
});

module.exports = ({ addComponents, theme }) => {
	addComponents(field(theme));
};

module.exports.field = field;
